// This file is part of MinIO Direct CSI
// Copyright (c) 2021 MinIO, Inc.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package main

import (
	"bytes"
	"compress/gzip"
	"fmt"
	"io"
	"strings"
)

func bindata_read(data []byte, name string) ([]byte, error) {
	gz, err := gzip.NewReader(bytes.NewBuffer(data))
	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	var buf bytes.Buffer
	_, err = io.Copy(&buf, gz)
	gz.Close()

	if err != nil {
		return nil, fmt.Errorf("Read %q: %v", name, err)
	}

	return buf.Bytes(), nil
}

var _go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsidrives_yaml = []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\x5b\xdd\x6f\xdb\xc8\x11\x7f\xd7\x5f\x31\x50\x0b\xc4\x4e\x45\x2a\xce\xb5\xe9\x9d\x80\x20\x48\x9d\xba\x08\x72\xc9\x19\xb1\x9b\x87\x5a\x6e\x6f\x48\x8e\xa8\x3d\x93\xbb\xbc\xdd\xa5\x6d\xa5\xe8\xff\x5e\xcc\x2e\x29\xea\x83\xa4\x65\xb7\x01\x8a\x82\xfb\x24\xee\xc7\xec\xec\x7c\xfc\x66\x76\x07\x1a\x05\x41\x30\xc2\x42\x7c\x21\x6d\x84\x92\x33\xc0\x42\xd0\xbd\x25\xc9\x5f\x26\xbc\xf9\xde\x84\x42\x4d\x6f\x4f\x46\x37\x42\x26\x33\x38\x2d\x8d\x55\xf9\x67\x32\xaa\xd4\x31\xbd\xa3\x85\x90\xc2\x0a\x25\x47\x39\x59\x4c\xd0\xe2\x6c\x04\x80\x52\x2a\x8b\xdc\x6d\xf8\x13\x20\x56\xd2\x6a\x95\x65\xa4\x83\x94\x64\x78\x53\x46\x14\x95\x22\x4b\x48\x3b\xe2\xf5\xd6\xb7\x2f\xc2\x3f\x84\x2f\x46\x00\xb1\x26\xb7\xfc\x52\xe4\x64\x2c\xe6\xc5\x0c\x64\x99\x65\x23\x00\x89\x39\xcd\x20\x11\x9a\x62\x1b\x1b\x91\x68\x71\x4b\x26\xf4\xdf\x61\x6c\x44\x98\x0b\x19\x0a\x35\x32\x05\xc5\xbc\x77\xaa\x55\x59\xd4\x0b\x36\x27\x78\x52\x15\x7f\xfe\x6c\xef\xdc\xa4\xd3\x8b\xf7\xef\x98\xaa\x1b\xc8\x84\xb1\x1f\x5a\x06\x7f\x14\xc6\xba\x09\x45\x56\x6a\xcc\xf6\x38\x72\x63\x46\xc8\xb4\xcc\x50\xef\x8e\x8e\x00\x4c\xac\x0a\x9a\xc1\x69\x56\x1a\x4b\x7a\x04\x50\xc9\xc0\xf1\x13\x54\xa7\xbc\x3d\xc1\xac\x58\xe2\x89\x27\x16\x2f\x29\x47\xcf\x2e\x80\x2a\x48\xbe\x3d\x7f\xff\xe5\xbb\x8b\xad\x6e\x80\x42\xab\x82\xb4\x15\xf5\xc9\x7c\xdb\xd0\xef\x46\x2f\x40\x42\x26\xd6\xa2\xb0\x4e\xfa\xcf\x98\xa0\x9f\x05\x09\x2b\x96\x0c\xd8\x25\xd5\xac\x51\x52\xf1\x00\x6a\x01\x76\x29\x0c\x68\x2a\x34\x19\x92\x5e\xd5\x5b\x84\x81\x27\xa1\x04\x15\xfd\xc2\x72\x87\x0b\xd2\x4c\x06\xcc\x52\x95\x59\xc2\xf6\x70\x4b\xda\x82\xa6\x58\xa5\x52\x7c\x5d\xd3\x36\x60\x95\xdb\x34\x43\x4b\x95\x88\x9b\x26\xa4\x25\x2d\x31\x83\x5b\xcc\x4a\x9a\x00\xca\x04\x72\x5c\x81\x26\xde\x05\x4a\xb9\x41\xcf\x4d\x31\x21\x7c\x54\x9a\x40\xc8\x85\x9a\xc1\xd2\xda\xc2\xcc\xa6\xd3\x54\xd8\xda\xae\x63\x95\xe7\xa5\x14\x76\x35\x75\x26\x2a\xa2\xd2\x2a\x6d\xa6\x09\xdd\x52\x36\x35\x22\x0d\x50\xc7\x4b\x61\x29\xb6\xa5\xa6\x29\x16\x22\x70\xac\x4b\x67\xdb\x61\x9e\xfc\x46\x57\x9e\x60\x9e\x6d\xf1\x6a\x57\xac\x5e\x63\xb5\x90\xe9\xc6\x80\xb3\xb3\x1e\x0d\xb0\xa9\x81\x30\x80\xd5\x52\x7f\x8a\x46\xd0\xdc\xc5\xd2\xf9\xfc\xe7\x8b\x4b\xa8\xb7\x76\xca\xd8\x95\xbe\x93\x7b\xb3\xd0\x34\x2a\x60\x81\x09\xb9\x20\xed\x95\xb8\xd0\x2a\x77\x34\x49\x26\x85\x12\xd2\xba\x8f\x38\x13\x24\x77\xc5\x6f\xca\x28\x17\x96\xf5\xfe\x6b\x49\xc6\xb2\xae\x42\x38\x75\xce\x0e\x11\x41\x59\x24\x68\x29\x09\xe1\xbd\x84\x53\xcc\x29\x3b\x45\x43\xdf\x5c\x01\x2c\x69\x13\xb0\x60\x0f\x53\xc1\x26\x4e\xed\x4e\xf6\x52\xdb\x18\xa8\x51\xa4\x69\xed\xfe\xe5\x34\x59\x03\xc4\x4f\x77\x92\x92\xdd\xd1\x1d\x4d\xb3\x08\x85\xa6\x64\x6f\x96\x67\x24\x52\x2a\x23\xdc\x75\x29\x07\x1e\x97\x28\xa4\xdd\xa7\x8e\x49\xe2\x70\x18\xb3\xf3\x4e\x0e\x7b\xa4\xd2\x2b\x05\x6e\x95\xce\x29\x39\x53\x3a\xc7\x16\x06\xba\x05\xc3\x6d\x21\x32\x32\x2b\x63\x29\x6f\x1b\x7d\x80\x2d\x80\x85\xd2\x31\xf5\xad\x6c\x17\x18\xb7\x5c\x95\xd2\xfe\x54\x6c\x04\xa3\xdd\x26\x2c\xe5\x1d\x43\x0f\x32\x56\x4f\x40\xad\x71\xd5\x3a\x7e\x1f\x70\xb4\xd3\x92\x2c\x99\x80\xc3\x49\x50\xad\xb0\x2a\x17\x71\x17\xc3\xce\x13\x9f\x24\xaa\xa2\xd4\xe9\x93\x44\xd5\xa9\xfc\xda\x56\xb7\x89\x06\x3b\x06\x7f\x90\x3b\x59\xb4\xa5\x39\xd4\xa1\x30\xcb\x54\xcc\x88\x72\x8a\x05\xc6\xc2\xae\xf6\x4f\xb5\xf0\xc6\xc8\x81\xe1\xd5\xef\x3b\x4e\xc4\x41\x23\x75\x31\x76\xb3\xc5\x4a\x7a\x87\x69\xd1\x7c\xa7\x41\x6c\xb9\xf0\xf8\xb4\x26\xe1\xd2\x1b\x14\xd2\x40\x42\x16\x45\x66\x98\x2f\x50\x92\x00\x19\x40\xac\x0f\x98\x04\x71\xa9\xf5\x3e\xaa\x36\xa2\xa1\x75\x64\x7d\x7b\xfe\x1e\xea\x1c\x2b\x84\x20\x08\xe0\x92\xbb\x8d\xd5\x65\x6c\x39\x40\xf0\xa1\x64\x42\x89\xdb\xc9\x2b\xa2\x95\x6c\x69\x98\x09\x8e\xc4\xce\x42\x01\x3d\xbc\x2f\x04\x65\x09\x14\x68\x97\x10\x7a\xa5\x84\x8d\x40\x42\x80\x33\xa5\x81\xee\x31\x2f\x32\x9a\x74\x9a\x12\x9c\x29\x75\xe1\x16\x57\x8c\xfd\xd3\x0d\x4d\xa7\xf0\x79\x1d\x76\xdc\x6e\x2a\x32\xa4\x6f\x7d\x3e\xe8\xf2\x82\x56\x92\x0b\xa5\x9e\x99\x5a\x46\x5e\x1e\x61\x4d\xf0\x83\x54\x77\xb2\x8d\x55\xc7\x07\xea\x0e\x83\x9f\x8f\xdf\xde\xa2\xc8\x30\xca\x68\x3e\x9e\xc0\x7c\x7c\xae\x55\xaa\xc9\x70\x62\xc6\x1d\x9c\x3f\xcc\xc7\xef\x28\xd5\x98\x50\x32\x1f\xd7\xdb\xfd\xae\x40\x1b\x2f\x3f\x92\x4e\xe9\x03\xad\x5e\xf3\x26\xed\xf4\xb7\xe6\x5f\x58\x8d\x96\xd2\xd5\xeb\x9c\x17\xae\x69\xb1\xcf\x5f\xae\x0a\x7a\x9d\x63\xb1\xd5\xf9\x11\x8b\x87\xa9\xaf\x8d\xcc\xc0\xd5\x35\xc7\xae\xdb\x93\xb0\x31\xbc\x9f\x7f\x31\x4a\xce\xe6\xe3\x46\x22\x13\x95\xb3\xf9\x16\x76\x35\x1f\xb7\x52\xdd\x62\x75\x36\x1f\x3b\x66\xe7\x63\xd8\x3a\xf2\x6c\x3e\x66\xb6\xb8\x5b\x2b\xab\xa2\x72\x31\x9b\x8f\xa3\x95\x25\x33\x39\x99\x68\x2a\x26\x9c\xa0\xbe\x6e\x76\x9d\x8f\x7f\x6e\x3f\x82\xac\x4f\xac\xec\x92\xb4\xb7\x3b\x03\xff\x6a\x63\xad\x3f\x80\x00\x64\x68\xec\xa5\x46\x69\x44\x7d\x33\xe8\xc2\xec\x2d\x37\xdd\x5f\xc6\xfe\xe3\x53\x4c\x63\xc1\x72\x87\x73\xce\xfa\x30\x1d\x44\x01\xec\x9a\x0a\xfb\x1d\xa7\x4d\xec\xe2\xde\x26\x39\x6d\x45\xe9\x0e\x19\x56\xbe\xea\x33\xdd\x88\xe0\x6e\x49\x3d\x44\x97\x04\xa5\x4c\x48\x67\x2b\x4e\xee\xe2\x06\x53\x96\x28\x53\xce\xa6\xe0\x3d\x83\x02\x3a\xb7\xe7\x4c\xeb\x86\x7d\x61\xc2\x0b\xbb\xa9\x96\xa6\xce\x14\xdd\xf9\x98\x03\xf7\xc5\xb8\xe2\x7d\xbf\x22\xef\x92\xcd\x38\xa6\xc2\xb2\x93\x84\x1d\x04\x6b\x98\xe5\xfc\x2e\x60\x8a\x4f\x0d\x96\x39\x19\x83\x5d\xe1\x69\x47\x71\xd5\x5c\x9f\x0e\x2f\xcb\x1c\x25\x68\xc2\x84\xf9\x6c\xc6\x64\x22\x62\xb4\x5d\xdb\x79\x9a\x1e\x92\x31\x52\xa5\x07\xbf\x46\x8f\x95\xaa\x38\x23\x8e\x88\x41\xd2\x39\x4e\x75\x80\x2e\x61\xe4\x78\xff\x23\xc9\xd4\x2e\x67\xf0\xdd\xcb\x3f\xbe\xfa\xfe\xa9\xb2\xf0\xa8\x48\xc9\x5f\x48\x92\x76\xe0\x78\x90\x58\xf6\x97\x6d\x64\xf9\xee\x7c\x61\x9d\xe2\x86\xe9\x7a\x4e\x8f\xfd\x55\x21\xa1\xb1\xbc\x3b\x34\x60\xc8\x42\x84\x86\x12\x28\x0b\x96\x13\x07\x04\x21\x8d\x45\x19\xd3\x04\xc4\xe2\x71\x9b\x88\x35\xae\x67\x2b\x38\x79\x39\x81\xa8\x52\xc5\x3e\xa2\x5f\xdd\x5f\x87\xfb\x47\xec\xa3\xfc\xc3\x64\x87\x7f\x61\x80\x55\xad\x16\xce\x5e\xe1\x4e\xd8\x25\xdf\x95\x5c\x24\xae\x6e\x97\x7d\x91\x18\xb6\xa3\x31\xad\xcf\xfd\x90\x77\xb4\x27\x21\xbe\xe5\x42\x8a\xbc\xcc\x67\xf0\xa2\xd7\x5c\xda\x73\x15\xdf\x34\xa1\x39\xd0\x46\xfc\xd4\x26\x2d\x41\x06\xd7\x54\x63\x9e\xa3\x15\x31\x88\x84\xef\x4f\x0b\x41\xfa\x10\x07\x62\x11\x54\x04\x39\xd9\xd8\x92\xf5\x33\x53\xa1\xe8\x86\x4b\x9d\x6b\x95\x94\x31\xe9\xdd\x2b\x69\xd3\xd4\xc2\x5d\xac\xc4\x42\xc4\x1b\x6a\x73\x17\x39\xe7\x8b\xfe\xf1\x01\xe8\x9e\x55\xb6\xbe\xca\x73\xb4\xee\x24\x99\x13\x4a\x21\x53\x53\xb1\xc8\xf7\x5a\x86\x39\x1f\xe2\xef\x96\xe4\xa2\x8f\x7b\xcc\xa8\x68\x69\x77\x0a\x23\x12\x6a\xbb\x85\xd5\x0d\x21\x2d\x51\xa3\xb4\x44\x09\x83\x27\x03\x46\x45\x63\x03\xe0\xb1\xb9\xee\x3e\x80\x1d\xe0\x01\xc7\x43\x30\x1f\xb5\xba\x3a\x3b\xdc\x39\x00\x70\x4e\x5e\xbc\xec\xb1\xb0\xf5\xac\x8e\x29\x05\x5a\x4b\x5a\xce\xe0\xef\x57\x6f\x83\xbf\x61\xf0\xf5\xfa\xa8\xfa\xf1\x22\xf8\xe1\x1f\x93\xd9\xf5\xf3\x8d\xcf\xeb\xe3\x37\xbf\x7d\x2a\xb4\xb5\xe5\xf9\x4d\xdb\x32\xd5\x2a\x7c\xd6\x19\x72\x6d\x0d\x13\x17\x5b\xd5\x02\x2e\x75\x49\x13\x38\xc3\xcc\xd0\x04\xfe\x2a\x5d\xf0\xeb\x12\x14\xc9\xb2\xe3\x7a\xc9\xd7\x95\x31\x93\x6a\xcf\x89\xdc\xb0\xdb\xa3\x7b\xbc\xda\xfb\x3f\xba\x26\x1e\x22\x10\x97\xd1\xaa\xc5\x26\x9e\x6d\x3c\xa7\x80\xc3\x61\xce\x95\xc3\x2a\x3f\x0f\x63\x95\x4f\x9b\xe7\x96\x4e\xc3\xe3\x4b\xc4\x47\x94\x2b\x68\xc0\xd6\x67\xcf\xbb\x1e\x61\x2c\xe7\xdf\x18\x6b\x65\xcc\xfa\x8d\xa9\xdb\x99\x33\x71\x43\xb0\x4e\xb3\x3d\xb4\x47\x14\xa3\xbb\x79\xe8\x48\x58\x8d\x7a\xb5\x71\xdd\x82\x18\xa5\x7b\x2d\x32\xb4\x28\xb3\x4e\xb2\x47\x86\x08\x42\xa9\x12\xda\x8f\x11\xc7\x1e\xf1\x31\x12\x99\xb0\x2b\xc6\xf4\x84\x62\x25\x17\x99\x70\x97\xa3\xee\x60\x91\x17\x4a\x5b\x94\xd6\xbb\xb1\xa6\x94\xee\x41\x58\xc8\x39\xf5\x25\xc3\x81\xe3\x28\x91\xe6\xe4\xe4\xe5\x77\x17\x65\x94\xa8\x1c\x85\x3c\xcb\xed\xf4\xf8\xcd\xd1\xaf\x25\x66\x8c\x98\xc9\x27\xcc\xe9\x2c\xb7\xc7\x07\x24\x07\x27\xaf\x1e\xf4\xc3\xa3\x2b\xef\x6d\xd7\x47\x57\x41\xf5\xeb\x79\xdd\x75\xfc\xe6\x68\x1e\xf6\x8e\x1f\x3f\x67\xd6\x36\x7c\xf8\xfa\x2a\x68\x1c\x38\xbc\x7e\x7e\xfc\x66\x63\xec\xf8\x89\xee\xdc\x7e\xfd\xf7\x2d\x68\x49\xaf\x5b\xa7\x55\x09\x5b\xeb\x98\x0f\x2e\xad\x43\x5e\xf5\xad\x43\x1d\xd7\xa6\x9e\x27\xac\xfe\xb7\x9a\xfd\x77\x9a\x1c\x8b\xe0\x86\x56\x2d\x38\xd6\xb1\x7b\xd7\x53\x4f\x8e\x45\xdb\x4b\xde\x45\x07\x4a\xf6\xe8\xa3\xef\x19\xad\x6f\x99\x26\xfa\x16\x8f\x28\x99\x4a\x45\x8c\xd9\x9f\x32\x15\xdf\x5c\x88\xaf\x2d\x00\xf7\x74\xda\xb9\x4a\x28\xfb\x54\xe6\x11\xe9\x47\x9d\xb5\xff\xbd\xaf\xf3\x69\xe7\x80\x77\xd1\x43\xed\xa6\xe7\x7d\xaf\xef\x6d\xaf\x87\x03\x86\x41\x06\x9e\x47\x2d\x2a\x50\x5b\xe7\x94\x9f\xda\xa2\x62\x9f\xe8\x0b\xb4\xcb\xc7\x6d\xb5\x5c\x99\x6f\x66\x08\x5a\x29\x7b\x5e\x9f\xe5\x51\x6c\x19\xd2\x02\x9f\x62\x43\x56\x15\x2a\x53\x69\x8b\xaf\x7c\xeb\x67\x76\xab\x2c\x66\xff\x7d\x57\xed\x7a\xc2\x65\x4d\x3f\xfc\x70\xbb\xbf\x3a\x58\x97\x51\x36\xba\x38\xa7\x1f\x75\x12\xf2\x57\xba\x19\x58\x5d\x7a\xe4\x34\x56\x69\x4c\x69\x06\x0b\x4e\xbc\xb6\xca\x9e\x11\xd9\xa1\xea\xb9\x6e\x43\xd5\x73\xa8\x7a\x0e\x55\xcf\xa1\xea\xb9\xbf\x72\xa8\x7a\xd6\xed\xff\xa8\xea\x19\xc7\x64\xcc\xa5\x78\x64\xca\x32\x14\x4b\x87\x62\x29\x0c\xc5\xd2\xa1\x58\xea\xdb\x50\x2c\x1d\x8a\xa5\x43\xb1\x74\x28\x96\xee\x52\x1e\x8a\xa5\x30\x14\x4b\x87\x62\xe9\x50\x2c\x1d\x8a\xa5\x43\xb1\x74\x28\x96\x0e\xc5\xd2\xa1\x58\x3a\x14\x4b\x87\x62\xe9\x50\x2c\x1d\x8a\xa5\xeb\xf6\x3f\x5d\x2c\x75\x3d\x4d\xca\xe8\x9f\x23\x7c\xa4\xdd\xfa\x2f\xeb\xd8\x27\x67\xf5\xdf\x53\xdd\xe7\xc6\x33\x2e\x5c\x5d\x8f\x3c\x55\x4a\xbe\xd4\x7f\x3d\xe5\xce\x7f\x07\x00\x00\xff\xff\xd4\x9e\x0b\xfd\x0f\x3c\x00\x00")

func go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsidrives_yaml() ([]byte, error) {
	return bindata_read(
		_go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsidrives_yaml,
		"go/src/github.com/minio/direct-csi/config/crd/direct.csi.min.io_directcsidrives.yaml",
	)
}

var _go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsivolumes_yaml = []byte("\x1f\x8b\x08\x00\x00\x00\x00\x00\x00\xff\xec\x5a\xdd\x6f\xdb\xc8\x11\x7f\xd7\x5f\x31\x50\x0b\xc4\x4e\x45\x2a\x4a\xda\xf4\x4e\x40\x10\x04\x4e\x53\x04\xb9\x14\x41\xec\xe6\xa1\x96\xdb\x1b\x92\x23\x6a\xcf\xe4\x2e\xb3\x1f\x8a\x75\x45\xff\xf7\x62\x76\x49\x91\xb2\x48\xc5\x49\x7b\x6f\xdc\x27\x71\x3f\x66\x66\xe7\xe3\x37\xb3\x03\x4d\xa2\x28\x9a\x60\x25\x3e\x91\x36\x42\xc9\x25\x60\x25\xe8\xce\x92\xe4\x2f\x13\xdf\xfe\x60\x62\xa1\xe6\xdb\xc5\xe4\x56\xc8\x6c\x09\x17\xce\x58\x55\x7e\x24\xa3\x9c\x4e\xe9\x35\xad\x85\x14\x56\x28\x39\x29\xc9\x62\x86\x16\x97\x13\x00\x94\x52\x59\xe4\x69\xc3\x9f\x00\xa9\x92\x56\xab\xa2\x20\x1d\xe5\x24\xe3\x5b\x97\x50\xe2\x44\x91\x91\xf6\xc4\x1b\xd6\xdb\x27\xf1\x9f\xe2\x27\x13\x80\x54\x93\x3f\x7e\x25\x4a\x32\x16\xcb\x6a\x09\xd2\x15\xc5\x04\x40\x62\x49\x4b\xc8\x84\xa6\xd4\xa6\x46\x6c\x55\xe1\x4a\x32\x71\x98\x88\x53\x23\xe2\x52\xc8\x58\xa8\x89\xa9\x28\x65\xe6\xb9\x56\xae\x6a\x4e\x74\x37\x04\x5a\xb5\x80\xe1\x72\xaf\xfd\xa6\x8b\xcb\xb7\x9f\x3c\x59\xbf\x52\x08\x63\xdf\xf5\xad\xfe\x24\x8c\xf5\x3b\xaa\xc2\x69\x2c\x8e\x85\xf2\x8b\x46\xc8\xdc\x15\xa8\x8f\x96\x27\x00\x26\x55\x15\x2d\xe1\xa2\x70\xc6\x92\x9e\x00\xd4\x8a\xf0\x32\x45\xf5\x55\xb7\x0b\x2c\xaa\x0d\x2e\x02\xb5\x74\x43\x25\x06\x91\x01\x54\x45\xf2\xd5\x87\xb7\x9f\x9e\x5d\x1e\x4c\x03\x54\x5a\x55\xa4\xad\x68\x6e\x17\x46\xc7\xc8\x9d\x59\x80\x8c\x4c\xaa\x45\x65\xbd\x09\x1e\x31\xc1\xb0\x0b\x32\xb6\x2e\x19\xb0\x1b\x6a\x44\xa3\xac\x96\x01\xd4\x1a\xec\x46\x18\xd0\x54\x69\x32\x24\x83\xbd\x0f\x08\x03\x6f\x42\x09\x2a\xf9\x85\x75\x0f\x97\xa4\x99\x0c\x98\x8d\x72\x45\xc6\x4e\xb1\x25\x6d\x41\x53\xaa\x72\x29\x7e\xdd\xd3\x36\x60\x95\x67\x5a\xa0\xa5\x5a\xc9\xed\x10\xd2\x92\x96\x58\xc0\x16\x0b\x47\x33\x40\x99\x41\x89\x3b\xd0\xc4\x5c\xc0\xc9\x0e\x3d\xbf\xc5\xc4\xf0\x5e\x69\x02\x21\xd7\x6a\x09\x1b\x6b\x2b\xb3\x9c\xcf\x73\x61\x1b\xe7\x4e\x55\x59\x3a\x29\xec\x6e\xee\xfd\x54\x24\xce\x2a\x6d\xe6\x19\x6d\xa9\x98\x1b\x91\x47\xa8\xd3\x8d\xb0\x94\x5a\xa7\x69\x8e\x95\x88\xbc\xe8\xd2\x3b\x78\x5c\x66\xbf\xd3\x75\x38\x98\x47\x07\xb2\xda\x1d\x9b\xd7\x58\x2d\x64\xde\x59\xf0\xbe\x76\xc2\x02\xec\x6d\x20\x0c\x60\x7d\x34\xdc\xa2\x55\x34\x4f\xb1\x76\x3e\xfe\xe5\xf2\x0a\x1a\xd6\xde\x18\xf7\xb5\xef\xf5\xde\x1e\x34\xad\x09\x58\x61\x42\xae\x49\x07\x23\xae\xb5\x2a\x3d\x4d\x92\x59\xa5\x84\xb4\xfe\x23\x2d\x04\xc9\xfb\xea\x37\x2e\x29\x85\x65\xbb\x7f\x76\x64\x2c\xdb\x2a\x86\x0b\x1f\xf1\x90\x10\xb8\x2a\x43\x4b\x59\x0c\x6f\x25\x5c\x60\x49\xc5\x05\x1a\xfa\xcd\x0d\xc0\x9a\x36\x11\x2b\xf6\x61\x26\xe8\x82\xd5\xfd\xcd\x41\x6b\x9d\x05\x63\xd1\x3a\x73\xb8\xb5\x3f\xc2\x78\xe0\x16\x45\x81\x49\x41\x17\x58\x61\x2a\xec\xee\xfe\x06\x80\xb5\xd2\x25\xda\x25\x7b\xf2\xf3\x3f\x1e\xad\x06\x29\xd8\xcb\x73\x0f\x0a\xdd\x91\x2a\x99\x89\x0e\xae\x76\x87\xb0\x54\xf6\x4c\xdf\xf3\xae\xe9\x45\x43\xc2\x83\x32\x0a\x69\x20\x23\x8b\xa2\x30\x2c\x17\x28\x49\x80\x8c\x9d\x36\x44\x38\x41\xea\xb4\x3e\x76\x83\x56\x35\xb4\x87\x82\x57\x1f\xde\x42\x93\x19\x62\x88\xa2\x08\xae\x78\xda\x58\xed\x52\xcb\x1e\xcd\x97\x92\x19\x65\x9e\x53\xc0\xc3\x5e\xb2\xce\xb0\x10\x0c\x1d\xa8\x35\xee\x00\x83\x3f\xae\x05\x15\x19\x54\x68\x37\x10\x07\xa3\xc4\xad\x42\x62\x80\x37\x4a\x03\xdd\x61\x59\x15\x34\xeb\xa5\xcb\xaa\x85\x37\x4a\x5d\xfa\xc3\xb5\x60\xff\xf6\x4b\xf3\x39\x7c\xdc\xc7\x89\xe7\xa6\x12\x43\x7a\x1b\xb2\x98\x07\xb2\x5e\x92\x6b\xa5\x1e\x99\x46\x47\x41\x1f\x71\x43\xf0\x9d\x54\x5f\x64\x9f\xa8\x5e\x0e\xd4\xd4\x67\x2d\x80\xd5\xf4\x55\xe3\x43\xab\xe9\x0c\x56\xd3\x0f\x5a\xe5\x9a\x0c\xa7\x12\x9e\x60\xc0\x5b\x4d\x5f\x53\xae\x31\xa3\x6c\x35\x6d\xd8\xfd\xa1\x42\x9b\x6e\xde\x93\xce\xe9\x1d\xed\x5e\x30\x93\x7e\xfa\x07\xfb\x2f\xad\x46\x4b\xf9\xee\x45\xc9\x07\xf7\xb4\x38\xed\x5d\xed\x2a\x7a\x51\x62\x75\x30\xf9\x1e\xab\xaf\x53\xdf\x3b\x99\x81\xeb\x1b\x0e\xb6\xed\x22\x6e\x1d\xef\xe7\x5f\x8c\x92\xcb\xd5\xb4\xd5\xc8\x4c\x95\xec\xbe\x95\xdd\xad\xa6\xbd\x54\x0f\x44\x5d\xae\xa6\x5e\xd8\xd5\x14\x0e\xae\xbc\x5c\x4d\x59\x2c\x9e\xd6\xca\xaa\xc4\xad\x97\xab\x69\xb2\xb3\x64\x66\x8b\x99\xa6\x6a\xc6\x19\xf5\x45\xcb\x75\x35\xfd\xb9\xff\x0a\xb2\xb9\xb1\xb2\x1b\xd2\xc1\xef\x0c\xfc\xa7\x4f\xb4\x61\x20\x08\xa3\x40\x63\xaf\x34\x4a\x23\x9a\x7a\xa6\x7f\xdf\xbd\x30\x3d\x3e\xc6\xf1\x13\x72\xa2\xb1\x60\x79\xc2\x07\x67\x73\x99\x01\xa2\x00\x76\x4f\x85\xe3\x8e\x71\x9e\x43\x3c\xf8\x24\xe7\x59\x94\xfe\x92\x71\x1d\xab\x21\x35\x27\x04\x5f\x36\x74\x82\xe8\x86\xc0\xc9\x8c\x74\xb1\xe3\x6c\x94\xb6\x98\xb2\x41\x99\x33\xfc\xc3\x5b\x06\x05\xf4\x61\xcf\xa9\xe1\x96\x63\x61\xc6\x07\x87\xa9\x3a\xd3\xa4\x36\x7f\x3f\x96\xc0\x7f\x31\xae\x84\xd8\xaf\xc9\xfb\xec\x98\xa6\x54\x59\x0e\x92\x78\x80\x60\x03\xb3\x9c\x90\x22\xa6\x38\xb0\x6f\x20\x47\xb4\xa3\x24\x63\x30\x7f\x98\xe1\xea\xbd\x21\x7f\x6f\x5c\x89\x12\x34\x61\xc6\x72\xb6\x6b\x32\x13\x29\xda\x21\x76\x81\x66\x80\x64\x4c\x94\x0b\xe0\xd7\xda\xb1\x36\x15\xa7\xf0\x84\x18\x24\x7d\xe0\xd4\x17\x18\x52\x46\x89\x77\x3f\x91\xcc\xed\x66\x09\xcf\x9e\xfe\xf9\xf9\x0f\xdf\xab\x8b\x80\x8a\x94\xfd\x95\x24\x69\x0f\x8e\x0f\x52\xcb\xf1\xb1\x4e\x59\xe2\xef\x17\x37\x39\x39\xce\xf7\x7b\x4e\xf8\x5f\x9d\x12\x5a\xcf\xfb\x82\x06\x0c\x59\x48\xd0\x50\x06\xae\x62\x3d\x71\x42\x10\xd2\x58\x94\x29\xcd\x40\xac\xbf\x8d\x89\xd8\xe3\x7a\xb1\x83\xc5\xd3\x19\x24\xb5\x29\x8e\x11\xfd\xfa\xee\x26\x3e\xbe\xe2\x29\xca\x3f\xce\xee\xc9\x2f\x0c\xb0\xa9\xd5\xda\xfb\x2b\x7c\x11\x76\xc3\xc5\x9d\xcf\xc4\x75\x39\x7c\x2a\x13\xc3\x61\x36\xa6\xfd\xbd\xbf\x16\x1d\xfd\x45\x48\x18\xa5\x90\xa2\x74\xe5\x12\x9e\x9c\x74\x97\xfe\x5a\x25\x0c\x4d\x68\x1e\xe8\x23\x61\x6b\x5b\x96\x20\x83\x6b\xae\xb1\x2c\xd1\x8a\x14\x44\xc6\x05\xdf\x5a\x90\x7e\x48\x00\xb1\x0a\x6a\x82\x5c\x6c\x1c\xe8\xfa\x91\xa9\x51\xb4\x13\x52\x1f\xb4\xca\x5c\x4a\xfa\x7e\x0d\xdd\x0e\xb5\x06\xb6\x86\x58\x8b\xb4\x63\x36\x5f\x79\xfa\x58\x0c\xaf\x25\xa0\x3b\x36\xd9\xfe\xed\xc1\xd9\x7a\x90\x64\x49\x28\x85\xcc\x4d\x2d\x22\x17\xe2\x0c\x73\x21\xc5\x7f\xd9\x90\xcf\x3e\xfe\xf5\x55\xd3\xd2\xfe\x16\x46\x64\xa4\x69\x98\x2c\x42\xee\x50\xa3\xb4\x44\x19\x83\x27\x03\x46\x4d\xa3\x03\xf0\xd8\xd6\xe7\x5f\xc1\x0e\x08\x80\x13\x20\x98\xaf\x5a\xd7\xfa\x1e\x77\x1e\x00\x38\x8b\x27\x4f\x4f\x78\xd8\x7e\xd7\xc0\x96\x0a\x2d\x3f\xf8\x96\xf0\xcf\xeb\x57\xd1\x3f\x30\xfa\xf5\xe6\xac\xfe\xf1\x24\xfa\xf1\x5f\xb3\xe5\xcd\xe3\xce\xe7\xcd\xf9\xcb\xdf\x7f\x2f\xb4\xf5\xd5\xf9\xed\x38\x70\xd5\x3a\x7d\x36\x15\x72\xe3\x0d\x33\x9f\x5b\xd5\x1a\xae\x34\xbf\x4c\xdf\x60\x61\x68\x06\x7f\x97\x3e\xf9\x0d\x29\x8a\xa4\x2b\x87\x98\x46\x30\x65\x52\xfd\x35\x91\x5f\xf6\x3c\x86\xd7\x6b\xde\xdf\xab\x12\xbf\xe1\x21\x0a\xf1\x15\xad\x5a\x77\xf1\xac\xf3\xfe\x03\x8f\xc3\x5c\x2b\xc7\x75\x7d\x1e\xa7\xaa\x9c\xb7\xef\xc3\x41\xc7\xe3\x47\xc4\x7b\x94\x3b\x68\xc1\x36\x54\xcf\xf7\x23\xc2\x58\xae\xbf\x31\xd5\xca\x98\xfd\xa3\x78\x38\x98\x0b\x71\x4b\xb0\x2f\xb3\x03\xb4\x27\x94\xa2\x7f\x79\xe8\x44\x58\x8d\x7a\xd7\x79\x6e\x41\x8a\xd2\x3f\x6f\x0d\xad\x5d\x31\x48\xf6\xcc\x10\x41\x2c\x55\x46\xc7\x39\xe2\x3c\x20\x3e\x26\xa2\x10\x76\xc7\x98\x9e\x51\xaa\xe4\xba\x10\xfe\x71\x34\x9c\x2c\xca\x4a\x69\x8b\xd2\x86\x30\xd6\x94\xd3\x1d\x08\x0b\x25\x97\xbe\x64\x38\x71\x9c\x65\xd2\x2c\x16\x4f\x9f\x5d\xba\x24\x53\x25\x0a\xf9\xa6\xb4\xf3\xf3\x97\x67\x9f\x1d\x16\x8c\x98\xd9\xdf\xb0\xa4\x37\xa5\x3d\x7f\x40\x71\xb0\x78\xfe\xd5\x38\x3c\xbb\x0e\xd1\x76\x73\x76\x1d\xd5\xbf\x1e\x37\x53\xe7\x2f\xcf\x56\xf1\xc9\xf5\xf3\xc7\x2c\x5a\x27\x86\x6f\xae\xa3\x36\x80\xe3\x9b\xc7\xe7\x2f\x3b\x6b\xe7\xdf\x19\xce\x9a\x3e\x3b\xa1\x29\xeb\xf3\xde\xa8\xa7\xbc\xee\xdd\x56\x17\x6c\xbd\x6b\x21\xb9\xf4\x2e\x05\xd3\xf7\x2e\x0d\x3c\x9b\x06\x3a\x0f\xdd\x45\xff\x12\x3e\x5a\xbb\x8b\x6e\x5d\x42\x5a\x92\x25\x13\xf1\xf3\x2c\x2a\xb1\x8a\x6e\x69\xd7\x83\x63\x03\xdc\x8f\x49\x04\x86\x25\x56\xc7\xdd\x07\xce\xcc\xa4\x3f\xa0\xdd\x1c\xd3\x3f\x61\x91\x4c\x8b\x6d\x0f\x90\x9c\x38\xb1\x51\xc6\x7e\x33\x1b\x0e\x3c\x76\xf5\x6f\x3a\x64\x2c\xe6\x42\xe6\xdf\xcc\xcc\x2a\x8b\xc5\x6f\xd1\xe4\x71\x86\xb2\xff\x3f\xdd\x5e\x17\x3b\x8e\x92\x68\xdf\x1b\x9b\x0c\x9e\x0c\x75\xee\x12\xac\x76\xc1\x9d\x8c\x55\x9a\x1f\x48\xb0\xe6\x6c\x74\xd0\xbc\x4e\xc8\x8e\xbd\xeb\xfd\x18\x7b\xd7\x63\xef\x7a\xec\x5d\x8f\xbd\xeb\xb1\x77\x3d\xf6\xae\xc7\xde\xf5\xd8\xbb\x1e\x7b\xd7\x63\xef\x7a\xec\x5d\xc3\xd8\xbb\x3e\x94\x6c\xec\x5d\x8f\xbd\xeb\x83\x31\xf6\xae\x8f\xc6\xd8\xbb\x1e\x7b\xd7\x30\xf6\xae\xc7\xde\xf5\xd8\xbb\x1e\x7b\xd7\x61\xfc\x6f\xbd\x6b\x3f\xd3\xe6\xd1\xf0\x46\x0b\xf0\x73\xf0\x27\xf1\x69\xc8\x58\xcd\xbf\xbe\xfd\x67\xa7\xb7\x05\xd7\x37\x93\x40\x95\xb2\x4f\xcd\xff\xb9\x79\xf2\xbf\x01\x00\x00\xff\xff\x1f\x92\xb3\x34\x69\x2f\x00\x00")

func go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsivolumes_yaml() ([]byte, error) {
	return bindata_read(
		_go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsivolumes_yaml,
		"go/src/github.com/minio/direct-csi/config/crd/direct.csi.min.io_directcsivolumes.yaml",
	)
}

// Asset loads and returns the asset for the given name.
// It returns an error if the asset could not be found or
// could not be loaded.
func Asset(name string) ([]byte, error) {
	cannonicalName := strings.Replace(name, "\\", "/", -1)
	if f, ok := _bindata[cannonicalName]; ok {
		return f()
	}
	return nil, fmt.Errorf("Asset %s not found", name)
}

// AssetNames returns the names of the assets.
func AssetNames() []string {
	names := make([]string, 0, len(_bindata))
	for name := range _bindata {
		names = append(names, name)
	}
	return names
}

// _bindata is a table, holding each asset generator, mapped to its name.
var _bindata = map[string]func() ([]byte, error){
	"go/src/github.com/minio/direct-csi/config/crd/direct.csi.min.io_directcsidrives.yaml":  go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsidrives_yaml,
	"go/src/github.com/minio/direct-csi/config/crd/direct.csi.min.io_directcsivolumes.yaml": go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsivolumes_yaml,
}

// AssetDir returns the file names below a certain
// directory embedded in the file by go-bindata.
// For example if you run go-bindata on data/... and data contains the
// following hierarchy:
//     data/
//       foo.txt
//       img/
//         a.png
//         b.png
// then AssetDir("data") would return []string{"foo.txt", "img"}
// AssetDir("data/img") would return []string{"a.png", "b.png"}
// AssetDir("foo.txt") and AssetDir("notexist") would return an error
// AssetDir("") will return []string{"data"}.
func AssetDir(name string) ([]string, error) {
	node := _bintree
	if len(name) != 0 {
		cannonicalName := strings.Replace(name, "\\", "/", -1)
		pathList := strings.Split(cannonicalName, "/")
		for _, p := range pathList {
			node = node.Children[p]
			if node == nil {
				return nil, fmt.Errorf("Asset %s not found", name)
			}
		}
	}
	if node.Func != nil {
		return nil, fmt.Errorf("Asset %s not found", name)
	}
	rv := make([]string, 0, len(node.Children))
	for name := range node.Children {
		rv = append(rv, name)
	}
	return rv, nil
}

type _bintree_t struct {
	Func     func() ([]byte, error)
	Children map[string]*_bintree_t
}

var _bintree = &_bintree_t{nil, map[string]*_bintree_t{
	"go": {nil, map[string]*_bintree_t{
		"src": {nil, map[string]*_bintree_t{
			"github.com": {nil, map[string]*_bintree_t{
				"minio": {nil, map[string]*_bintree_t{
					"direct-csi": {nil, map[string]*_bintree_t{
						"config": {nil, map[string]*_bintree_t{
							"crd": {nil, map[string]*_bintree_t{
								"direct.csi.min.io_directcsidrives.yaml":  {go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsidrives_yaml, map[string]*_bintree_t{}},
								"direct.csi.min.io_directcsivolumes.yaml": {go_src_github_com_minio_direct_csi_config_crd_direct_csi_min_io_directcsivolumes_yaml, map[string]*_bintree_t{}},
							}},
						}},
					}},
				}},
			}},
		}},
	}},
}}
